# Variable Protocols
A way to specify common variables of data inputs in the field of data science and machine learning.

## Installation
`pip install variale_protocols`

## Goals
* specify common variables of data inputs in the field of data science and machine learning.
* structural typing, only sum types and product types (In the general sense, not ML family ADT)
* there should be one way to type one variable group
* serialization in the future (probably in Dhall)

## NonGoals
* compatability with any current stuff